Module ops

Module ops 

Structs

Add
Term that represents the arithmetic operation on mathematical integers and whose evaluations always panics on overflow of the base type
And
Term that represents the arithmetic operation on the base type and whose evalutations just call the base type operation
Div
Term that represents the arithmetic operation on mathematical integers and whose evaluations always panics on overflow of the base type
Mul
Term that represents the arithmetic operation on mathematical integers and whose evaluations always panics on overflow of the base type
Neg
Term that represents the arithmetic operation on mathematical integers and whose evaluations always panics on overflow of the base type
Not
Or
Term that represents the arithmetic operation on the base type and whose evalutations just call the base type operation
Rem
Term that represents the arithmetic operation on mathematical integers and whose evaluations always panics on overflow of the base type
Sub
Term that represents the arithmetic operation on mathematical integers and whose evaluations always panics on overflow of the base type
XAdd
Term that represents the arithmetic operation on the base type and whose evalutations just call the base type operation
XDiv
Term that represents the arithmetic operation on the base type and whose evalutations just call the base type operation
XMul
Term that represents the arithmetic operation on the base type and whose evalutations just call the base type operation
XNeg
Term that represents the arithmetic operation on the base type and whose evalutations just call the base type operation
XRem
Term that represents the arithmetic operation on the base type and whose evalutations just call the base type operation
XSub
Term that represents the arithmetic operation on the base type and whose evalutations just call the base type operation
Xor
Term that represents the arithmetic operation on the base type and whose evalutations just call the base type operation

Traits

ConstOps
Asserts that all core::ops traits that are implemented are a constant function of the arguments (or panic) Meaning that for two sequences of arguments which are equal (according to Eq or TotalCmp for floats), then the results are also equal, if neither panics

Functions

Add
Term that represents the arithmetic operation on mathematical integers and whose evaluations always panics on overflow of the base type
And
Term that represents the arithmetic operation on the base type and whose evalutations just call the base type operation
Div
Term that represents the arithmetic operation on mathematical integers and whose evaluations always panics on overflow of the base type
Mul
Term that represents the arithmetic operation on mathematical integers and whose evaluations always panics on overflow of the base type
Neg
Term that represents the arithmetic operation on mathematical integers and whose evaluations always panics on overflow of the base type
Not
Or
Term that represents the arithmetic operation on the base type and whose evalutations just call the base type operation
Rem
Term that represents the arithmetic operation on mathematical integers and whose evaluations always panics on overflow of the base type
Sub
Term that represents the arithmetic operation on mathematical integers and whose evaluations always panics on overflow of the base type
XAdd
Term that represents the arithmetic operation on the base type and whose evalutations just call the base type operation
XDiv
Term that represents the arithmetic operation on the base type and whose evalutations just call the base type operation
XMul
Term that represents the arithmetic operation on the base type and whose evalutations just call the base type operation
XNeg
Term that represents the arithmetic operation on the base type and whose evalutations just call the base type operation
XRem
Term that represents the arithmetic operation on the base type and whose evalutations just call the base type operation
XSub
Term that represents the arithmetic operation on the base type and whose evalutations just call the base type operation
Xor
Term that represents the arithmetic operation on the base type and whose evalutations just call the base type operation