XSub

Function XSub 

pub fn XSub<a: Term, b: Term>(a: Value<a>, b: Value<b>) -> Value<XSub<a, b>>
where a::Type: Sub<b::Type> + ConstOps,
Term that represents the arithmetic operation on the base type and whose evalutations just call the base type operation

For primitive integers, this may be the operation on mathematical integers or on the Z mod 2**b ring depending on whether overflow checks are on or not.