Rem

Struct Rem 

pub struct Rem<a: Term, b: Term> { /* private fields */ }
Term that represents the arithmetic operation on mathematical integers and whose evaluations always panics on overflow of the base type

Implementations

Source

impl<a0: Term, b0: Term> Rem<a0, b0>

pub fn eq<a1: Term, b1: Term>( _: ValueEq<a0, a1>, _: ValueEq<b0, b1>, ) -> ValueEq<Self, Rem<a1, b1>>