XDiv

Struct XDiv 

pub struct XDiv<a: Term, b: Term> { /* private fields */ }
Term that represents the arithmetic operation on the base type and whose evalutations just call the base type operation

For primitive integers, this may be the operation on mathematical integers or on the Z mod 2**b ring depending on whether overflow checks are on or not.

Implementations

Source

impl<a0: Term, b0: Term> XDiv<a0, b0>

pub fn eq<a1: Term, b1: Term>( _: ValueEq<a0, a1>, _: ValueEq<b0, b1>, ) -> ValueEq<Self, XDiv<a1, b1>>