Module term

Module term 

Structs

Def
Erased
An erased term, used by DPair to erase values
Value
Value of term A the A::Type value is guaranteed to always be the same for a given type A and instantiation of its lifetimes (this must be respected when unsafely calling new_unchecked or unsafely implementing Eval)
ValueCmp

Traits

Term
TotalCmp

Functions

Def
total_cmp
total_eq
Return evidence of x == y or x != y. Uses total_cmp()
total_le
Return evidence of x <= y or x > y
total_lt
Return evidence of x < y or x >= y
value_cmp
value_eq
Return evidence of x == y or x != y
value_le
Return evidence of x <= y
value_le_or_gt
Return evidence of x <= y or x > y
value_lt
Return evidence of x < y
value_lt_or_ge
Return evidence of x < y or x >= y
value_partial_cmp
Return evidence of x < y or x > y

Type Aliases

ValueEq
ValueGe
ValueGt
ValueLe
ValueLt
ValueNe
ValueOrdering