pub struct Rem<a: Term, b: Term> { /* private fields */ }Expand description
Term that represents the arithmetic operation on mathematical integers and whose evaluations always panics on overflow of the base type
Implementations