Structs
- Def
- Erased
- An erased term, used by DPair to erase values
- Value
- Value of term A the A::Type value is guaranteed to always be the same for a given type A and instantiation of its lifetimes (this must be respected when unsafely calling new_unchecked or unsafely implementing Eval)
- Value
Cmp
Traits
Functions
- Def
- total_
cmp - total_
eq - Return evidence of x == y or x != y. Uses total_cmp()
- total_
le - Return evidence of x <= y or x > y
- total_
lt - Return evidence of x < y or x >= y
- value_
cmp - value_
eq - Return evidence of x == y or x != y
- value_
le - Return evidence of x <= y
- value_
le_ or_ gt - Return evidence of x <= y or x > y
- value_
lt - Return evidence of x < y
- value_
lt_ or_ ge - Return evidence of x < y or x >= y
- value_
partial_ cmp - Return evidence of x < y or x > y